@@ -18,10 +18,12 @@
 
 # import re
 # import utils.objectUtils as objUtils
-import utils.parse_sql as sql
 import logging
 import utils.objectUtils as obj
+import utils.sql_facade as sql
 logger = logging.getLogger(__name__)
+
+
 BOOL_TRUE_SYNONYMS = ["TRUE", "true", "True", "yes", "y", "1"]
 BOOL_FALSE_SYNONYMS = ["FALSE", "false", "False", "no", "n", "0"]
 VALID_PYTHON_TYPES = {
