@@ -3,7 +3,7 @@ import hashlib
 import string
 import random
 import utils.objectUtils as objUtils
-import utils.string_format as strFormat 
+import utils.string_format as strFormat
 
 def hash(value):
     '''
@@ -87,6 +87,94 @@ def rand(length=12, **kwargs):
 
     return ''.join(random.SystemRandom().choice(choices) for _ in range(length))
 
+def title_divider(message='',**kwargs):
+    '''
+        Generate a console log divider with centered message.
+
+        ==================   hi there   ===================
+
+        ----------
+
+        Arguments
+        -------------------------
+
+        [`message`=''] {str}
+            The message text to center in the divider. If not provided the divider will be solid.
+
+
+        Keyword Arguments
+        -------------------------
+        [`white_space`=1] {int}
+            How many spaces should be on each side of the message as padding.
+
+        [`length`=100] {int}
+            How many characters wide the title should be.
+
+        [`line_char`="="] {str}
+            The character to use as the "line" of the divider.
+
+        Return {str}
+        ----------------------
+        The divider string.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 04-28-2022 08:03:09
+        `memberOf`: string_generation
+        `version`: 1.0
+        `method_name`: title_divider
+        # @xxx [04-28-2022 08:08:04]: documentation for title_divider
+    '''
+
+
+    length = objUtils.get_kwarg(['length'], 100, int, **kwargs)
+    line_char = objUtils.get_kwarg(['line_char'], "=", str, **kwargs)
+    white_space = objUtils.get_kwarg(['white_space'], 1, int, **kwargs)
+
+    if isinstance(line_char,(str,int)) is False:
+        line_char = "="
+    if len(line_char) > 1:
+        line_char = line_char[0]
+
+    msg_len = len(message)
+    if length < msg_len:
+        # print(f"Length {length} must be greater than the length of the message {msg_len}.")
+        return message
+
+    if msg_len == 0:
+        return line_char * length
+
+    # @Mstep [] calculate how many "line" chars must fill the excess space.
+    char_count = (length / len(line_char)) - (msg_len+(white_space*2))
+    # @Mstep [] calculate how many line chars should be on each side of the message.
+    half_char = int(char_count / 2)
+
+    # @Mstep [] generate the line char string.
+    char_str = f"{line_char * half_char}"
+    padding = ' ' * white_space
+    line = f"{char_str}{padding}{message}{padding}{char_str}"
+
+
+    if len(line) < length:
+        dif = length - len(line)
+        lchar = ''
+        rchar = line_char * dif
+        if (dif % 2) == 0:
+            rchar = line_char * (dif / 2)
+            lchar = line_char * (dif / 2)
+        line = f"{char_str}{lchar}{padding}{message}{padding}{rchar}{char_str}"
+
+    # print(len(line))
+    return line
+
+# def is_even(num):
+#     if (num % 2) == 0:
+#         return True
+#     return False
+
+# print(title_divider())
+# print(title_divider('boobs',line_char='_',length=75))
 
 def variations(value,**kwargs):
     '''
@@ -106,7 +194,7 @@ def variations(value,**kwargs):
         `case`=True {bool}
             if True case variations are generated:
             snake case, screaming snake case, title case, reverse title case.
-            
+
             This will apply to all typos as well.
 
         Return
@@ -120,10 +208,10 @@ def variations(value,**kwargs):
     '''
     typos = objUtils.get_kwarg(['typos'], True, bool, **kwargs)
     case_variations = objUtils.get_kwarg(['case'], True, bool, **kwargs)
-    
+
     if isinstance(value,(str)):
         value = [value]
-    
+
     result = []
     for term in value:
         # value = str(value)
@@ -197,11 +285,11 @@ def missed_key_typos(word):
     word = word.lower()
     typos = []
     # length = len(word)
-    
+
     for idx,letter in enumerate(word):
-        tempword = replace_at(word,'',idx)            
+        tempword = replace_at(word,'',idx)
         typos.append(tempword)
-        
+
     if len(typos) > 1:
         typos = list(set(typos))
     return typos
@@ -209,14 +297,14 @@ def missed_key_typos(word):
 def wrong_key_typos(word,keyboard=TYPO_PROXIMITY_KEYBOARD):
     word = word.lower()
     typos = []
-    
-    
+
+
     for letter in word:
         if letter in keyboard:
             temp_word = word
             for char in keyboard[letter]:
                 typos.append(temp_word.replace(letter,char).strip())
-                
+
     # print(f"typos: ",typos)
     if len(typos) > 1:
         typos = list(set(typos))
@@ -225,7 +313,7 @@ def wrong_key_typos(word,keyboard=TYPO_PROXIMITY_KEYBOARD):
 def transposed_chars(word):
     word = word.lower()
     typos = []
-    
+
     for idx,letter in enumerate(word):
         tempword = word
         tempchar = tempword[idx]
@@ -235,13 +323,13 @@ def transposed_chars(word):
             typos.append(tempword)
     # print(f"typos: ",typos)
     if len(typos) > 1:
-        typos = list(set(typos))    
+        typos = list(set(typos))
     return typos
 
 def double_char_typos(word):
     word = word.lower()
     typos = []
-    
+
     for idx,letter in enumerate(word):
         tempword = word[0:idx]
         tempword += word[idx-1:]
@@ -249,7 +337,7 @@ def double_char_typos(word):
             # tempword += word[idx + 1]
         if len(tempword) == len(word) + 1:
             typos.append(tempword)
-        
+
     if len(typos) > 1:
         typos = list(set(typos))
     return typos
